# Django SSR

[![build-status-image]][travis]
[![coverage-status-image]][codecov]

[build-status-image]: https://secure.travis-ci.org/GreyZmeem/django-ssr.svg?branch=master
[travis]: https://travis-ci.org/GreyZmeem/django-ssr?branch=master
[coverage-status-image]: https://img.shields.io/codecov/c/github/GreyZmeem/django-ssr/master.svg
[codecov]: https://codecov.io/github/GreyZmeem/django-ssr?branch=master
